# LANTSA

LANTSA is a landmark-based transferable subspace analysis tool for single-cell and spatial transcriptomics.

Please visit [LANTSA documentation website](https://lantsa.readthedocs.io/) for details about installation, tutorials, API and references.
